pub mod download_progress {
    use eframe::egui::{Ui, ProgressBar};
    use crate::app::SinfarInstallerApp;
    use std::time::Duration;

    fn format_bytes(bytes: f64) -> String {
        const KB: f64 = 1024.0;
        const MB: f64 = KB * 1024.0;

        if bytes >= MB {
            format!("{:.1} MB/s", bytes / MB)
        } else if bytes >= KB {
            format!("{:.1} KB/s", bytes / KB)
        } else {
            format!("{:.0} B/s", bytes)
        }
    }

    fn format_duration(duration: Duration) -> String {
        let secs = duration.as_secs();
        if secs >= 3600 {
            format!("{:02}:{:02}:{:02} remaining", secs / 3600, (secs % 3600) / 60, secs % 60)
        } else {
            format!("{:02}:{:02} remaining", secs / 60, secs % 60)
        }
    }

    pub fn render(ui: &mut Ui, app: &mut SinfarInstallerApp) {
        ui.heading("Downloading Sinfar Custom Content");
        ui.add_space(10.0);
        
        ui.vertical(|ui| {
            ui.horizontal(|ui| {
                ui.label("Downloading:");
                ui.add(ProgressBar::new(app.download_progress).show_percentage());
            });
            
            if app.download_progress > 0.0 && app.download_progress < 1.0 {
                ui.horizontal(|ui| {
                    ui.label(format_bytes(app.download_speed));
                    ui.label(" • ");
                    ui.label(format_duration(app.estimated_remaining));
                });
            }
        });
        
        if let Some(error) = &app.download_error {
            ui.colored_label(eframe::egui::Color32::RED, format!("Error: {}", error));
            if ui.button("Retry").clicked() {
                app.download_error = None;
                app.download_progress = 0.0;
                app.start_download();
            }
        }
    }
}